Authors
-------

Created Oct 2021 by Matthias Cuntz from the `JAMS Python library`_.

It is distributed under the MIT License, see LICENSE file.

Copyright (c) 2012-2022 Matthias Cuntz, Juliane Mai, Stephan Thober, and Arndt
Piayda

Contributors
    * `Matthias Cuntz`_, E-mail: mc (at) macu (dot) de
    * `Juliane Mai`_, E-mail: juliane (dot) mai (at) uwaterloo (dot) ca
    * `Stephan Thober`_, E-mail: stephan (dot) thober (at) ufz (dot) de
    * `Arndt Piayda`_, E-mail: arndt (dot) piayda (at) thuenen (dot) de

.. _Arndt Piayda: https://github.com/peterchenchenchen
.. _JAMS Python library: https://github.com/mcuntz/jams_python
.. _Juliane Mai: https://github.com/julemai
.. _Matthias Cuntz: https://github.com/mcuntz
.. _Stephan Thober: https://github.com/StephanThober
